==> kif_lib-0.4.1.tar.gz: kif_lib-0.4.1/kif_lib/vocabulary/wd/item.py <==
# Copyright (C) 2023-2024 IBM Corp.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from .prelude import Q

# autopep8: off
# flake8: noqa

_1 = Q(199, '1')
acetone = Q(49546, 'acetone')
Adam = Q(70899, 'Adam')
Adam_and_Eve = Q(58701, 'Adam and Eve')
Africa = Q(15, 'Africa')
Amazonas = Q(40040, 'Amazonas')
Americas = Q(828, 'Americas')
Argentina = Q(414, 'Argentina')
aromatic_hydrocarbon = Q(230731, 'aromatic hydrocarbon')
Asia = Q(48, 'Asia')
Atlantic_Ocean = Q(97, 'Atlantic Ocean')
Australia = Q(408, 'Australia')
autobahn_in_Germany = Q(313301, 'autobahn in Germany')
benzene = Q(2270, 'benzene')
Bolivia = Q(750, 'Bolivia')
Brazil = Q(155, 'Brazil')
Brazilian_Sign_Language = Q(3436689, 'Brazilian Sign Language')
bridge = Q(12280, 'bridge')
business = Q(4830453, 'business')
caffeine = Q(60235, 'caffeine')
CAS_Common_Chemistry = Q(18907859, 'CAS Common Chemistry')
characterization = Q(2165586, 'characterization')
chemical_compound = Q(11173, 'chemical compound')
chemical_entity = Q(43460564, 'chemical entity')
ChemIDplus = Q(20593, 'ChemIDplus')
chemistry = Q(2329, 'chemistry')
ChemSpider = Q(2311683, 'ChemSpider')
child = Q(7569, 'child')
Chile = Q(298, 'Chile')
coffee = Q(8486, 'coffee')
Colombia = Q(739, 'Colombia')
comma_separated_values = Q(935809, 'comma-separated values')
continent_ = Q(5107, 'continent')
country_ = Q(6256, 'country')
dalton = Q(483261, 'dalton')
data_set = Q(1172284, 'data set')
degree_Celsius = Q(25267, 'degree Celsius')
degree_Fahrenheit = Q(42289, 'degree Fahrenheit')
dog = Q(144, 'dog')
dopamine = Q(170304, 'dopamine')
Easter = Q(21196, 'Easter')
ECHA_Substance_Infocard_database = Q(59911453, 'ECHA Substance Infocard database')
El_Capitan = Q(1124852, 'El Capitan')
electronvolt = Q(83327, 'electronvolt')
Endicott = Q(3459600, 'Endicott')
English = Q(1860, 'English')
English_Wikipedia = Q(328, 'English Wikipedia')
Europe = Q(46, 'Europe')
Eve = Q(830183, 'Eve')
exact_match_ = Q(39893449, 'exact match')
Fall_of_man = Q(1135949,  'Fall of man')
FDA_approved = Q(111972129, 'FDA-approved')
female = Q(6581072, 'female')
female_given_name = Q(11879590, 'female given name')
female_human = Q(84048852, 'female human')
feminine = Q(1775415, 'feminine')
flame_retardant = Q(902863, 'flame retardant')
France = Q(142, 'France')
French_Guiana = Q(3769, 'French Guiana')
frog = Q(3116510, 'frog')
Garden_of_Eden = Q(19014, 'Garden of Eden')
Garden_of_Eden = Q(19014, 'Garden of Eden')
Germany = Q(183, 'Germany')
Global_Substance_Registration_System = Q(116031405, 'Global Substance Registration System')
gram_per_100_gram_of_solvent = Q(21127659, 'gram per 100 gram of solvent')
gram_per_cubic_centimetre = Q(13147228, 'gram per cubic centimetre')
gram_per_kilogram = Q(21061369, 'gram per kilogram')
gram_per_mole = Q(28924752, 'gram per mole')
Guinea_pig = Q(79803, 'Guinea pig')
Guyana = Q(734, 'Guyana')
Hazardous_Substances_Data_Bank = Q(5687720, 'Hazardous Substances Data Bank')
height_ = Q(208826, 'height')
human = Q(5, 'human')
human_biblical_figure = Q(20643955, 'human biblical figure')
IBM = Q(37156, 'IBM')
IBM_AIX = Q(269856, 'IBM_AIX')
infant = Q(998, 'infant')
inhalation = Q(840343, 'inhalation')
intraperitoneal_injection = Q(1400536, 'intraperitoneal injection')
intravenous_infusion_and_defusion = Q(640448, 'intravenous infusion and defusion')
intravenous_injection = Q(1369403, 'intravenous injection')
joule_per_mole_kelvin_difference = Q(69427692, 'joule per mole kelvin difference')
kelvin = Q(11579, 'kelvin')
kilogram = Q(11570, 'kilogram')
kind_of_quantity = Q(110653654, 'kind of quantity')
laboratory_mouse = Q(2842787, 'laboratory mouse')
laboratory_rat = Q(3089676, 'laboratory rat')
Latin_America = Q(12585, 'Latin America')
lion = Q(140, 'lion')
liquid = Q(11435, 'liquid')
machine_learning = Q(2539, 'machine learning')
male = Q(6581097, 'male')
male_human = Q(84048850, 'male human')
mammal = Q(7377, 'mammal')
man = Q(8441, 'man')
masculine = Q(499327, 'masculine')
mass_ = Q(11423, 'mass')
mathematics = Q(395, 'mathematics')
methanol = Q(14982, 'methanol')
metre = Q(11573, 'metre')
microgram_per_kilogram = Q(107313731, 'microgram per kilogram')
milligram_per_kilogram = Q(21091747, 'milligram per kilogram')
minute = Q(7727, 'minute')
Monte_Pascoal = Q(1499212, 'Monte Pascoal')
Mount_Everest = Q(513, 'Mount Everest')
mountain = Q(8502, 'mountain')
mythical_character = Q(4271324, 'mythical character')
Nepal = Q(837, 'Nepal')
New_York_City = Q(60, 'New York City')
North_America = Q(49, 'North America')
Oceania = Q(55643, 'Oceania')
oral_administration = Q(285166, 'oral administration')
Paraguay = Q(733, 'Paraguay')
part = Q(15989253, 'part')
parts_per_million = Q(21006887, 'parts per million')
patent = Q(253623, 'patent')
per_and_polyfluoroalkyl_substances = Q(648037, 'per- and polyfluoroalkyl substances')
Peru =  Q(419, 'Peru')
physics = Q(413, 'physics')
Pico_31_de_Março = Q(1264913, 'Pico 31 de Março')
Pico_da_Neblina = Q(739484, 'Pico da Neblina')
Portuguese = Q(5146, 'Portuguese')
product = Q(2424752, 'product')
proleptic_Gregorian_calendar = Q(1985727, 'proleptic Gregorian calendar')
proleptic_Julian_calendar = Q(1985786, 'proleptic Julian calendar')
protoplast = Q(4349921, 'protoplast')
PubChem = Q(278487, 'PubChem')
rabbit = Q(9394, 'rabbit')
rectal_administration = Q(419892, 'rectal administration')
report = Q(10870555, 'report')
Rio_de_Janeiro = Q(8678, 'Rio de Janeiro')
river = Q(4022, 'river')
scholarly_article = Q(13442814, 'scholarly article')
scientist = Q(901, 'scientist')
second = Q(11574, 'second')
skin_absorption = Q(4669896, 'skin absorption')
slope = Q(944588, 'slope')
sodium_bicarbonate = Q(179731, 'sodium bicarbonate')
South_America = Q(18, 'South America')
Spanish = Q(1321, 'Spanish')
subcutaneous_injection = Q(2035485, 'subcutaneous injection')
Supercalifragilisticexpialidocious = Q(103, 'Supercalifragilisticexpialidocious')
type_of_a_chemical_entity = Q(113145171, 'type of a chemical entity')
unit_of_mass = Q(3647172, 'unit of mass')
United_States_of_America = Q(30, 'United States of America')
Uruguay = Q(77, 'Uruguay')
vendor = Q(1762621, 'vendor')
Venezuela = Q(717, 'Venezuela')
verb = Q(24905, 'verb')
water = Q(283, 'water')
Watson = Q(12253, 'Watson')
Wikidata = Q(2013, 'Wikidata')
Wikidata_property_for_physical_quantities = Q(21077852, 'Wikidata property for physical quantities')
Wikidata_property_related_to_animals_and_zoology = Q(57633168, 'Wikidata property related to animals and zoology')
Wikidata_property_related_to_chemistry = Q(21294996, 'Wikidata property related to chemistry')
Wikidata_property_related_to_medicine = Q(19887775, 'Wikidata property related to medicine')
Wikidata_property_to_identify_substances = Q(19833835, 'Wikidata property to identify substances')
woman = Q(467, 'woman')

__all__ = (
    '_1',
    'acetone',
    'Adam',
    'Adam_and_Eve',
    'Africa',
    'Amazonas',
    'Americas',
    'Argentina',
    'aromatic_hydrocarbon',
    'Asia',
    'Atlantic_Ocean',
    'Australia',
    'autobahn_in_Germany',
    'benzene',
    'Bolivia',
    'Brazil',
    'Brazilian_Sign_Language',
    'bridge',
    'business',
    'caffeine',
    'CAS_Common_Chemistry',
    'characterization',
    'chemical_compound',
    'chemical_entity',
    'ChemIDplus',
    'chemistry',
    'ChemSpider',
    'child',
    'Chile',
    'coffee',
    'Colombia',
    'comma_separated_values',
    'continent_',
    'country_',
    'dalton',
    'data_set',
    'degree_Celsius',
    'degree_Fahrenheit',
    'dog',
    'dopamine',
    'Easter',
    'ECHA_Substance_Infocard_database',
    'El_Capitan',
    'electronvolt',
    'Endicott',
    'English',
    'English_Wikipedia',
    'Europe',
    'Eve',
    'exact_match_',
    'Fall_of_man',
    'FDA_approved',
    'female',
    'female_given_name',
    'female_human',
    'feminine',
    'flame_retardant',
    'France',
    'French_Guiana',
    'frog',
    'Garden_of_Eden',
    'Garden_of_Eden',
    'Germany',
    'Global_Substance_Registration_System',
    'gram_per_100_gram_of_solvent',
    'gram_per_cubic_centimetre',
    'gram_per_kilogram',
    'gram_per_mole',
    'Guinea_pig',
    'Guyana',
    'Hazardous_Substances_Data_Bank',
    'height_',
    'human',
    'human_biblical_figure',
    'IBM',
    'IBM_AIX',
    'infant',
    'inhalation',
    'intraperitoneal_injection',
    'intravenous_infusion_and_defusion',
    'intravenous_injection',
    'joule_per_mole_kelvin_difference',
    'kelvin',
    'kilogram',
    'kind_of_quantity',
    'laboratory_mouse',
    'laboratory_rat',
    'Latin_America',
    'lion',
    'liquid',
    'machine_learning',
    'male',
    'male_human',
    'mammal',
    'man',
    'masculine',
    'mass_',
    'mathematics',
    'methanol',
    'metre',
    'microgram_per_kilogram',
    'milligram_per_kilogram',
    'minute',
    'Monte_Pascoal',
    'Mount_Everest',
    'mountain',
    'mythical_character',
    'Nepal',
    'New_York_City',
    'North_America',
    'Oceania',
    'oral_administration',
    'Paraguay',
    'part',
    'parts_per_million',
    'patent',
    'per_and_polyfluoroalkyl_substances',
    'Peru',
    'physics',
    'Pico_31_de_Março',
    'Pico_da_Neblina',
    'Portuguese',
    'product',
    'proleptic_Gregorian_calendar',
    'proleptic_Julian_calendar',
    'protoplast',
    'PubChem',
    'rabbit',
    'rectal_administration',
    'report',
    'Rio_de_Janeiro',
    'river',
    'scholarly_article',
    'scientist',
    'second',
    'skin_absorption',
    'slope',
    'sodium_bicarbonate',
    'South_America',
    'Spanish',
    'subcutaneous_injection',
    'Supercalifragilisticexpialidocious',
    'type_of_a_chemical_entity',
    'unit_of_mass',
    'United_States_of_America',
    'Uruguay',
    'vendor',
    'Venezuela',
    'verb',
    'water',
    'Watson',
    'Wikidata',
    'Wikidata_property_for_physical_quantities',
    'Wikidata_property_related_to_animals_and_zoology',
    'Wikidata_property_related_to_chemistry',
    'Wikidata_property_related_to_medicine',
    'Wikidata_property_to_identify_substances',
    'woman',
)

==> kif_lib-0.11.0.tar.gz: kif_lib-0.11.0/kif_lib/vocabulary/wd/item.py <==
# Copyright (C) 2023-2025 IBM Corp.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from .prelude import Q

# autopep8: off
# flake8: noqa

_1 = Q(199, '1')
acetone = Q(49546, 'acetone')
Adam = Q(70899, 'Adam')
Adam_and_Eve = Q(58701, 'Adam and Eve')
administrative_territorial_entity_of_Brazil = Q(10374536, 'administrative territorial entity of Brazil')
Africa = Q(15, 'Africa')
Alan_Turing = Q(7251, 'Alan Turing')
algorithm = Q(8366, 'algorithm')
Amazonas = Q(40040, 'Amazonas')
Americas = Q(828, 'Americas')
Argentina = Q(414, 'Argentina')
aromatic_compound = Q(19834818, 'aromatic compound')
aromatic_hydrocarbon = Q(230731, 'aromatic hydrocarbon')
Asia = Q(48, 'Asia')
Atlantic_Ocean = Q(97, 'Atlantic Ocean')
Australia = Q(408, 'Australia')
autobahn_in_Germany = Q(313301, 'autobahn in Germany')
benzene = Q(2270, 'benzene')
Bolivia = Q(750, 'Bolivia')
Brazil = Q(155, 'Brazil')
Brazilian_Portuguese = Q(750553, 'Brazilian Portuguese')
Brazilian_Sign_Language = Q(3436689, 'Brazilian Sign Language')
bridge = Q(12280, 'bridge')
business = Q(4830453, 'business')
caffeine = Q(60235, 'caffeine')
carbon = Q(623, 'carbon')
carbonic_acid = Q(104334, 'carbonic acid')
CAS_Common_Chemistry = Q(18907859, 'CAS Common Chemistry')
characterization = Q(2165586, 'characterization')
chemical_compound = Q(11173, 'chemical compound')
chemical_entity = Q(43460564, 'chemical entity')
ChemIDplus = Q(20593, 'ChemIDplus')
chemistry = Q(2329, 'chemistry')
ChemSpider = Q(2311683, 'ChemSpider')
child_ = Q(7569, 'child')
Chile = Q(298, 'Chile')
coffee = Q(8486, 'coffee')
Colombia = Q(739, 'Colombia')
comma_separated_values = Q(935809, 'comma-separated values')
CompTox_Chemistry_Dashboard = Q(26998510, 'CompTox Chemistry Dashboard')
continent_ = Q(5107, 'continent')
copyrighted = Q(50423863, 'copyrighted')
country_ = Q(6256, 'country')
dalton = Q(483261, 'dalton')
data_set = Q(1172284, 'data set')
database = Q(8513, 'database')
day = Q(573, 'day')
degree_Celsius = Q(25267, 'degree Celsius')
degree_Fahrenheit = Q(42289, 'degree Fahrenheit')
dog = Q(144, 'dog')
dopamine = Q(170304, 'dopamine')
drama_film = Q(130232, 'drama film')
Easter = Q(21196, 'Easter')
ECHA_Substance_Infocard_database = Q(59911453, 'ECHA Substance Infocard database')
El_Capitan = Q(1124852, 'El Capitan')
electronvolt = Q(83327, 'electronvolt')
Endicott = Q(3459600, 'Endicott')
English = Q(1860, 'English')
English_Wikipedia = Q(328, 'English Wikipedia')
entity = Q(35120, 'entity')
Europe = Q(46, 'Europe')
Eve = Q(830183, 'Eve')
exact_match_ = Q(39893449, 'exact match')
Fall_of_man = Q(1135949,  'Fall of man')
FDA_approved = Q(111972129, 'FDA-approved')
female = Q(6581072, 'female')
female_given_name = Q(11879590, 'female given name')
female_human = Q(84048852, 'female human')
feminine = Q(1775415, 'feminine')
flame_retardant = Q(902863, 'flame retardant')
flying_saucer = Q(5401971, 'flying saucer')
France = Q(142, 'France')
French_Guiana = Q(3769, 'French Guiana')
frog = Q(3116510, 'frog')
Garden_of_Eden = Q(19014, 'Garden of Eden')
Garden_of_Eden = Q(19014, 'Garden of Eden')
Germany = Q(183, 'Germany')
ginga = Q(1411420, 'ginga')
Ginga = Q(5563000, 'Ginga')
Global_Substance_Registration_System = Q(116031405, 'Global Substance Registration System')
GNU_General_Public_License = Q(7603, 'GNU General Public License')
gram_per_100_gram_of_solvent = Q(21127659, 'gram per 100 gram of solvent')
gram_per_cubic_centimetre = Q(13147228, 'gram per cubic centimetre')
gram_per_kilogram = Q(21061369, 'gram per kilogram')
gram_per_mole = Q(28924752, 'gram per mole')
Guinea_pig = Q(79803, 'Guinea pig')
Guyana = Q(734, 'Guyana')
Hazardous_Substances_Data_Bank = Q(5687720, 'Hazardous Substances Data Bank')
height_ = Q(208826, 'height')
house_cat = Q(146, 'house cat')
human = Q(5, 'human')
human_biblical_figure = Q(20643955, 'human biblical figure')
hydrogen = Q(556, 'hydrogen')
IBM = Q(37156, 'IBM')
IBM_AIX = Q(269856, 'IBM_AIX')
infant = Q(998, 'infant')
inhalation = Q(840343, 'inhalation')
intraperitoneal_injection = Q(1400536, 'intraperitoneal injection')
intravenous_infusion_and_defusion = Q(640448, 'intravenous infusion and defusion')
intravenous_injection = Q(1369403, 'intravenous injection')
joule_per_mole_kelvin_difference = Q(69427692, 'joule per mole kelvin difference')
kelvin = Q(11579, 'kelvin')
kilogram = Q(11570, 'kilogram')
kind_of_quantity = Q(110653654, 'kind of quantity')
laboratory_mouse = Q(2842787, 'laboratory mouse')
laboratory_rat = Q(3089676, 'laboratory rat')
Latin_America = Q(12585, 'Latin America')
lion = Q(140, 'lion')
liquid = Q(11435, 'liquid')
machine_learning = Q(2539, 'machine learning')
male = Q(6581097, 'male')
male_human = Q(84048850, 'male human')
mammal = Q(7377, 'mammal')
man = Q(8441, 'man')
masculine = Q(499327, 'masculine')
mass_ = Q(11423, 'mass')
mathematics = Q(395, 'mathematics')
methanol = Q(14982, 'methanol')
metre = Q(11573, 'metre')
microgram_per_kilogram = Q(107313731, 'microgram per kilogram')
middleware = Q(146768, 'middleware')
milligram_per_kilogram = Q(21091747, 'milligram per kilogram')
minute = Q(7727, 'minute')
Monte_Pascoal = Q(1499212, 'Monte Pascoal')
Mount_Everest = Q(513, 'Mount Everest')
mountain = Q(8502, 'mountain')
musician = Q(639669, 'musician')
mythical_character = Q(4271324, 'mythical character')
Nepal = Q(837, 'Nepal')
New_York_City = Q(60, 'New York City')
North_America = Q(49, 'North America')
Oceania = Q(55643, 'Oceania')
oral_administration = Q(285166, 'oral administration')
Paraguay = Q(733, 'Paraguay')
part = Q(15989253, 'part')
parts_per_million = Q(21006887, 'parts per million')
patent = Q(253623, 'patent')
per_and_polyfluoroalkyl_substances = Q(648037, 'per- and polyfluoroalkyl substances')
Peru =  Q(419, 'Peru')
physics = Q(413, 'physics')
Pico_31_de_Março = Q(1264913, 'Pico 31 de Março')
Pico_da_Neblina = Q(739484, 'Pico da Neblina')
Portuguese = Q(5146, 'Portuguese')
product = Q(2424752, 'product')
proleptic_Gregorian_calendar = Q(1985727, 'proleptic Gregorian calendar')
proleptic_Julian_calendar = Q(1985786, 'proleptic Julian calendar')
protoplast = Q(4349921, 'protoplast')
PubChem = Q(278487, 'PubChem')
rabbit = Q(9394, 'rabbit')
Raul = Q(13415699, 'Raul')
Raul_Seixas = Q(1392583, 'Raul Seixas')
rectal_administration = Q(419892, 'rectal administration')
report = Q(10870555, 'report')
Rio_de_Janeiro = Q(8678, 'Rio de Janeiro')
river = Q(4022, 'river')
Salvador = Q(36947, 'Salvador')
scholarly_article = Q(13442814, 'scholarly article')
scientist = Q(901, 'scientist')
second = Q(11574, 'second')
seculararchy = Q(859563, 'seculararchy')
skin_absorption = Q(4669896, 'skin absorption')
slope = Q(944588, 'slope')
sodium_bicarbonate = Q(179731, 'sodium bicarbonate')
South_America = Q(18, 'South America')
sovereign_state = Q(3624078, 'sovereign_state')
Spanish = Q(1321, 'Spanish')
state = Q(7275, 'state')
subcutaneous_injection = Q(2035485, 'subcutaneous injection')
summit = Q(207326, 'summit')
Supercalifragilisticexpialidocious = Q(103, 'Supercalifragilisticexpialidocious')
Suriname = Q(730, 'Suriname')
system_software = Q(676202, 'system software')
type_of_a_chemical_entity = Q(113145171, 'type of a chemical entity')
unit_of_mass = Q(3647172, 'unit of mass')
United_Kingdom = Q(145, 'United Kingdom')
United_States_of_America = Q(30, 'United States of America')
Uruguay = Q(77, 'Uruguay')
vendor = Q(1762621, 'vendor')
Venezuela = Q(717, 'Venezuela')
verb = Q(24905, 'verb')
water = Q(283, 'water')
Watson = Q(12253, 'Watson')
Wikidata = Q(2013, 'Wikidata')
Wikidata_metaproperty_for_ontology_mapping = Q(42842547, 'Wikidata metaproperty for ontology mapping')
Wikidata_property_for_an_identifier = Q(19847637, 'Wikidata property for an identifier')
Wikidata_property_for_ontology_mapping = Q(30249126, 'Wikidata property for ontology mapping')
Wikidata_property_for_physical_quantities = Q(21077852, 'Wikidata property for physical quantities')
Wikidata_property_related_to_animals_and_zoology = Q(57633168, 'Wikidata property related to animals and zoology')
Wikidata_property_related_to_biology = Q(22988603, 'Wikidata property related to biology')
Wikidata_property_related_to_chemistry = Q(21294996, 'Wikidata property related to chemistry')
Wikidata_property_related_to_medicine = Q(19887775, 'Wikidata property related to medicine')
Wikidata_property_to_identify_substances = Q(19833835, 'Wikidata property to identify substances')
Wilmslow = Q(2011497, 'Wilmslow')
woman = Q(467, 'woman')

__all__ = (
    '_1',
    'acetone',
    'Adam',
    'Adam_and_Eve',
    'administrative_territorial_entity_of_Brazil',
    'Africa',
    'Alan_Turing',
    'algorithm',
    'Amazonas',
    'Americas',
    'Argentina',
    'aromatic_compound',
    'aromatic_hydrocarbon',
    'Asia',
    'Atlantic_Ocean',
    'Australia',
    'autobahn_in_Germany',
    'benzene',
    'Bolivia',
    'Brazil',
    'Brazilian_Portuguese',
    'Brazilian_Sign_Language',
    'bridge',
    'business',
    'caffeine',
    'carbon',
    'carbonic_acid',
    'CAS_Common_Chemistry',
    'characterization',
    'chemical_compound',
    'chemical_entity',
    'ChemIDplus',
    'chemistry',
    'ChemSpider',
    'child_',
    'Chile',
    'coffee',
    'Colombia',
    'comma_separated_values',
    'CompTox_Chemistry_Dashboard',
    'continent_',
    'copyrighted',
    'country_',
    'dalton',
    'data_set',
    'database',
    'day',
    'degree_Celsius',
    'degree_Fahrenheit',
    'dog',
    'dopamine',
    'drama_film',
    'Easter',
    'ECHA_Substance_Infocard_database',
    'El_Capitan',
    'electronvolt',
    'Endicott',
    'English',
    'English_Wikipedia',
    'entity',
    'Europe',
    'Eve',
    'exact_match_',
    'Fall_of_man',
    'FDA_approved',
    'female',
    'female_given_name',
    'female_human',
    'feminine',
    'flame_retardant',
    'flying_saucer',
    'France',
    'French_Guiana',
    'frog',
    'Garden_of_Eden',
    'Garden_of_Eden',
    'Germany',
    'ginga',
    'Ginga',
    'Global_Substance_Registration_System',
    'GNU_General_Public_License',
    'gram_per_100_gram_of_solvent',
    'gram_per_cubic_centimetre',
    'gram_per_kilogram',
    'gram_per_mole',
    'Guinea_pig',
    'Guyana',
    'Hazardous_Substances_Data_Bank',
    'height_',
    'house_cat',
    'human',
    'human_biblical_figure',
    'hydrogen',
    'IBM',
    'IBM_AIX',
    'infant',
    'inhalation',
    'intraperitoneal_injection',
    'intravenous_infusion_and_defusion',
    'intravenous_injection',
    'joule_per_mole_kelvin_difference',
    'kelvin',
    'kilogram',
    'kind_of_quantity',
    'laboratory_mouse',
    'laboratory_rat',
    'Latin_America',
    'lion',
    'liquid',
    'machine_learning',
    'male',
    'male_human',
    'mammal',
    'man',
    'masculine',
    'mass_',
    'mathematics',
    'methanol',
    'metre',
    'microgram_per_kilogram',
    'middleware',
    'milligram_per_kilogram',
    'minute',
    'Monte_Pascoal',
    'Mount_Everest',
    'mountain',
    'musician',
    'mythical_character',
    'Nepal',
    'New_York_City',
    'North_America',
    'Oceania',
    'oral_administration',
    'Paraguay',
    'part',
    'parts_per_million',
    'patent',
    'per_and_polyfluoroalkyl_substances',
    'Peru',
    'physics',
    'Pico_31_de_Março',
    'Pico_da_Neblina',
    'Portuguese',
    'product',
    'proleptic_Gregorian_calendar',
    'proleptic_Julian_calendar',
    'protoplast',
    'PubChem',
    'rabbit',
    'Raul',
    'Raul_Seixas',
    'rectal_administration',
    'report',
    'Rio_de_Janeiro',
    'river',
    'Salvador',
    'scholarly_article',
    'scientist',
    'second',
    'seculararchy',
    'skin_absorption',
    'slope',
    'sodium_bicarbonate',
    'South_America',
    'sovereign_state',
    'Spanish',
    'state',
    'subcutaneous_injection',
    'summit',
    'Supercalifragilisticexpialidocious',
    'Suriname',
    'system_software',
    'type_of_a_chemical_entity',
    'unit_of_mass',
    'United_Kingdom',
    'United_States_of_America',
    'Uruguay',
    'vendor',
    'Venezuela',
    'verb',
    'water',
    'Watson',
    'Wikidata',
    'Wikidata_metaproperty_for_ontology_mapping',
    'Wikidata_property_for_an_identifier',
    'Wikidata_property_for_ontology_mapping',
    'Wikidata_property_for_physical_quantities',
    'Wikidata_property_related_to_animals_and_zoology',
    'Wikidata_property_related_to_biology',
    'Wikidata_property_related_to_chemistry',
    'Wikidata_property_related_to_medicine',
    'Wikidata_property_to_identify_substances',
    'Wilmslow',
    'woman',
)
